*$ CREATE UBSSET.FOR
*COPY UBSSET
*
*=== ubsset ===========================================================*
*
      SUBROUTINE UBSSET (     IR, RRHADR, IMPHAD, IMPLOW, IMPEMF,
     &                    IGCUTO, IGNONA, PNONAN, IGDWSC, FDOWSC,
     &                    JWSHPP,  WWLOW,  WWHIG,  WWMUL, EXPTR ,
     &                    ELECUT, GAMCUT,  LPEMF, ELPEMF, PLPEMF )

      INCLUDE '(DBLPRC)'
      INCLUDE '(DIMPAR)'
      INCLUDE '(IOUNIT)'
*
*----------------------------------------------------------------------*
*                                                                      *
*     Copyright (C) 1992-2005      by    Alfredo Ferrari & Paola Sala  *
*     All Rights Reserved.                                             *
*                                                                      *
*                                                                      *
*     User BiaSing SETting:                                            *
*                                                                      *
*     Created on 04 november 1992  by    Alfredo Ferrari & Paola Sala  *
*                                                   Infn - Milan       *
*                                                                      *
*     Last change on 31-aug-93     by    Alfredo Ferrari               *
*                                                                      *
*     !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!     *
*     !!!!!!!  WARNING: THIS ROUTINE IS CALLED MANY TIMES  !!!!!!!     *
*     !!!!!!!  FOR EACH REGION, BE SURE ALL PARAMETERS ARE !!!!!!!     *
*     !!!!!!!            PROPERLY SET AT EVERY CALL        !!!!!!!     *
*     !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!     *
*                                                                      *
*     Input variables:                                                 *
*                                                                      *
*                    Ir     = region number                            *
*                    Rrhadr = RR/Splitting factor to be applied to the *
*                             secondaries outcoming from hadronic      *
*                             interactions (see card BIASING)          *
*                    Imphad = Region importance for hadrons & muons    *
*                             x 10000 (see card BIASING)               *
*                    Implow = Region importance for low energy neutrons*
*                             x 10000 (see card BIASING)               *
*                    Impemf = Region importance for e+,e- and photons  *
*                             x 10000 (see card BIASING)               *
*                    Igcuto = Cut Off group index for low energy neut- *
*                             rons (see card LOW-BIAS)                 *
*                    Ignona = Non-analog absorption group index for    *
*                             low energy neutrons (see card LOW-BIAS)  *
*                    Pnonan = Non-analog absorption factor for         *
*                             low energy neutrons (see card LOW-BIAS)  *
*                    Igdwsc = Biased downscattering group index for    *
*                             low energy neutrons (see card LOW-DOWN)  *
*                    Fdowsc = Biased downscattering factor for         *
*                             low energy neutrons (see card LOW-DOWN)  *
*                    Jwshpp = Shape profile index for low energy       *
*                             neutrons (see cards WW-PROFI, WW-FACTO)  *
*                    Wwlow  = Weight Window lower level                *
*                             (see cards WW-FACTO, WW-PROFI, WW-THRES) *
*                    Wwhig  = Weight Window upper level                *
*                             (see cards WW-FACTO, WW-PROFI, WW-THRES) *
*                    Wwmul  = Weight Window multiplicative factor      *
*                             (see cards WW-FACTO, WW-PROFI, WW-THRES) *
*                    Exptr  = Exponential transform parameter          *
*                             (see card EXPTRANS)                      *
*                    Elecut = e+,e- cut-off                            *
*                             (see card EMFCUT)                        *
*                    Gamcut = Photon cut-off                           *
*                             (see card EMFCUT)                        *
*                    Lpemf  = Leading Particle biasing for e+,e-,      *
*                             photon  flag (see card EMFCUT/EMF-BIAS)  *
*                    Elpemf = Max e+/e- energy to apply leading parti- *
*                             cle biasing (see card EMF-BIAS)          *
*                    Plpemf = Max photon energy to apply leading parti-*
*                             cle biasing (see card EMF-BIAS)          *
*                                                                      *
*                                                                      *
*----------------------------------------------------------------------*
*
* Don't touch these lines
      HMPHAD = IMPHAD
      HMPEMF = IMPEMF
      HMPLOW = IMPLOW
      HMPHAD = 1.D-04 * HMPHAD
      HMPEMF = 1.D-04 * HMPEMF
      HMPLOW = 1.D-04 * HMPLOW
*
*  User written part .....
* Don't touch these lines
      IMPHAD = NINT ( 1.D+04 * HMPHAD )
      IMPEMF = NINT ( 1.D+04 * HMPEMF )
      IMPLOW = NINT ( 1.D+04 * HMPLOW )
      RETURN
*=== End of subroutine Ubsset =========================================*
      END

